# <span class="badge package-core"></span> publicdashboard

## Objects

 * <span class="badge object-type-class"></span> [PublicDashboard](./object-PublicDashboard.md)
## Builders

 * <span class="badge builder"></span> [PublicDashboard](./builder-PublicDashboard.md)
